==> dstack-0.18.35.tar.gz: dstack-0.18.35/src/dstack/_internal/proxy/lib/schemas/model_proxy.py <==
from typing import Any, Dict, List, Literal, Optional, Union

from dstack._internal.core.models.common import CoreModel

FinishReason = Literal["stop", "length", "tool_calls", "eos_token"]


class ChatMessage(CoreModel):
    role: str  # TODO(egor-s) types
    content: str


class ChatCompletionsRequest(CoreModel):
    messages: List[ChatMessage]
    model: str
    frequency_penalty: Optional[float] = 0.0
    logit_bias: Dict[str, float] = {}
    max_tokens: Optional[int] = None
    n: int = 1
    presence_penalty: float = 0.0
    response_format: Optional[Dict] = None
    seed: Optional[int] = None
    stop: Optional[Union[str, List[str]]] = None
    stream: bool = False
    temperature: Optional[float] = 1.0
    top_p: Optional[float] = 1.0
    tools: List[Any] = []
    tool_choice: Union[Literal["none", "auto"], Dict] = {}
    user: Optional[str] = None


class ChatCompletionsChoice(CoreModel):
    finish_reason: FinishReason
    index: int
    message: ChatMessage


class ChatCompletionsChunkChoice(CoreModel):
    delta: object
    logprobs: object = {}
    finish_reason: Optional[FinishReason]
    index: int


class ChatCompletionsUsage(CoreModel):
    completion_tokens: int
    prompt_tokens: int
    total_tokens: int


class ChatCompletionsResponse(CoreModel):
    id: str
    choices: List[ChatCompletionsChoice]
    created: int
    model: str
    system_fingerprint: str = ""
    object: Literal["chat.completion"] = "chat.completion"
    usage: ChatCompletionsUsage


class ChatCompletionsChunk(CoreModel):
    id: str
    choices: List[ChatCompletionsChunkChoice]
    created: int
    model: str
    system_fingerprint: str = ""
    object: Literal["chat.completion.chunk"] = "chat.completion.chunk"


class Model(CoreModel):
    object: Literal["model"] = "model"
    id: str
    created: int
    owned_by: str


class ModelsResponse(CoreModel):
    object: Literal["list"] = "list"
    data: List[Model]

==> dstack-0.18.38.tar.gz: dstack-0.18.38/src/dstack/_internal/proxy/lib/schemas/model_proxy.py <==
from typing import Any, Dict, List, Literal, Optional, Union

from dstack._internal.core.models.common import CoreModel


class ChatMessage(CoreModel):
    role: str  # TODO(egor-s) types
    content: str


class ChatCompletionsRequest(CoreModel):
    messages: List[ChatMessage]
    model: str
    frequency_penalty: Optional[float] = 0.0
    logit_bias: Dict[str, float] = {}
    max_tokens: Optional[int] = None
    n: int = 1
    presence_penalty: float = 0.0
    response_format: Optional[Dict] = None
    seed: Optional[int] = None
    stop: Optional[Union[str, List[str]]] = None
    stream: bool = False
    temperature: Optional[float] = 1.0
    top_p: Optional[float] = 1.0
    tools: List[Any] = []
    tool_choice: Union[Literal["none", "auto"], Dict] = {}
    user: Optional[str] = None


class ChatCompletionsChoice(CoreModel):
    finish_reason: str
    index: int
    message: ChatMessage


class ChatCompletionsChunkChoice(CoreModel):
    delta: object
    logprobs: object = {}
    finish_reason: Optional[str]
    index: int


class ChatCompletionsUsage(CoreModel):
    completion_tokens: int
    prompt_tokens: int
    total_tokens: int


class ChatCompletionsResponse(CoreModel):
    id: str
    choices: List[ChatCompletionsChoice]
    created: int
    model: str
    system_fingerprint: str = ""
    object: Literal["chat.completion"] = "chat.completion"
    usage: ChatCompletionsUsage


class ChatCompletionsChunk(CoreModel):
    id: str
    choices: List[ChatCompletionsChunkChoice]
    created: int
    model: str
    system_fingerprint: str = ""
    object: Literal["chat.completion.chunk"] = "chat.completion.chunk"


class Model(CoreModel):
    object: Literal["model"] = "model"
    id: str
    created: int
    owned_by: str


class ModelsResponse(CoreModel):
    object: Literal["list"] = "list"
    data: List[Model]
